@@ -90,8 +90,8 @@ class Model:
             "namespace": "",
         },
     )
-    pose: "Model.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Model.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -197,8 +197,8 @@ class Model:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Model.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Model.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -223,7 +223,7 @@ class Model:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -246,7 +246,7 @@ class Model:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
